@@ -40,6 +40,8 @@ from functools import reduce
 from functools import partial
 from itertools import product
 from collections import OrderedDict
+from dataclasses import asdict
+from dataclasses import dataclass
 
 from .types import configs_type
 from .types import general_config_type
@@ -422,15 +424,16 @@ def check(constraints: Dict[str, Union[str, List[str]]], *, raise_error: bool =
 # util modules
 
 
-T = TypeVar("T", bound="WithRegister", covariant=True)
+TRegister = TypeVar("TRegister", bound="WithRegister", covariant=True)
+TDataClass = TypeVar("TDataClass", bound="DataClassBase")
 
 
-class WithRegister(Generic[T]):
-    d: Dict[str, Type[T]]
+class WithRegister(Generic[TRegister]):
+    d: Dict[str, Type[TRegister]]
     __identifier__: str
 
     @classmethod
-    def get(cls, name: str) -> Type[T]:
+    def get(cls, name: str) -> Type[TRegister]:
         return cls.d[name]
 
     @classmethod
@@ -438,7 +441,7 @@ class WithRegister(Generic[T]):
         return name in cls.d
 
     @classmethod
-    def make(cls, name: str, config: Dict[str, Any]) -> T:
+    def make(cls, name: str, config: Dict[str, Any]) -> TRegister:
         return cls.get(name)(**config)  # type: ignore
 
     @classmethod
@@ -446,7 +449,7 @@ class WithRegister(Generic[T]):
         cls,
         names: Union[str, List[str]],
         configs: configs_type = None,
-    ) -> List[T]:
+    ) -> List[TRegister]:
         if configs is None:
             configs = {}
         if isinstance(names, str):
@@ -485,6 +488,15 @@ class WithRegister(Generic[T]):
         return issubclass(cls.d[name], cls)
 
 
+@dataclass
+class DataClassBase(ABC):
+    def asdict(self) -> Dict[str, Any]:
+        return asdict(self)
+
+    def copy(self: TDataClass) -> TDataClass:
+        return type(self)(**shallow_copy_dict(asdict(self)))
+
+
 class SanityChecker:
     @staticmethod
     def int(n):
